// @ts-check
// Note: type annotations allow type checking and IDEs autocompletion

const lightCodeTheme = require('prism-react-renderer/themes/github');
const darkCodeTheme = require('prism-react-renderer/themes/dracula');

/** @type {import('@docusaurus/types').Config} */
const config = {
  title: 'Lydra | Artisans DevOps',
  tagline: 'Nous aidons les entreprises du numérique à déployer leurs applications web rapidement et sans coupure de service.',
  url: process.env.DOCUSAURUS_URL || 'https://new.lydra.fr"',
  baseUrl: process.env.DOCUSAURUS_BASEURL || '/',
  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',
  favicon: 'img/favicon.png',
  organizationName: 'Lydra/www', // Usually your GitHub org/user name.
  projectName: 'Site lydra.fr', // Usually your repo name.
  staticDirectories: ['static', 'blog/images'],

  i18n: {
    defaultLocale: 'fr',
    locales: ['fr'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: false,
        blog: {
          blogSidebarTitle: 'Articles récents',
          showReadingTime: true,
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          editUrl:
            'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: require.resolve('./src/css/custom.css'),
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      colorMode: {
        defaultMode: 'dark',
        respectPrefersColorScheme: false,
      },
      navbar: {
        hideOnScroll: false,
        logo: {
          alt: 'Lydra Logo',
          src: 'img/logo_lydra.svg',
        },
        items: [
          {
            to: '/', 
            label: 'Accueil', 
            position: 'right',
            activeBaseRegex: '^/$'
          },
          {
            type: 'dropdown',
            label: 'DevOps',
            position: 'right',
            items: [
              {
                label: '📻 Le Podcast',
                to: '/radio-devops',
              },
              {
                label: 'Les Compagnons',
                href: 'https://www.compagnons-devops.fr/',
              },
            ],
          },
          {
            type: 'dropdown',
            label: 'SaaS',
            position: 'right',
            items: [
              {
                label: '🔧 Boîte à outils',
                href: 'https://www.lydra.eu/bao',
              },
              {
                label: '🔑 Clé en main',
                href: 'https://www.lydra.eu/cem',
              },
              {
                label: '🐸 Froggit',
                href: 'https://froggit.fr/',
              },
            ],
          },
          {
            to: 'https://www.compagnons-devops.fr/mentor', 
            label: '🎓  Mentorat', 
            position: 'right'
          },
          {
            to: '/nos-services', 
            label: 'Nos Services', 
            position: 'right'
          },
          {
            type: 'dropdown',
            label: 'Qui sommes nous ?',
            position: 'right',
            items: [
              {
                label: 'L\'équipe',
                to: '/#team',
                activeBasePath: '/#'
              },
              {
                label: 'Nos inspirations',
                to: '/nos-inspirations',
              },
              {
                label: 'Contact',
                to: '/contacts',
              },
            ],
          },
          {
            to: '/blog', 
            label: '📰  Blog', 
            position: 'right'
          },
        ],
      },
      footer: {
        links: [
              {
                label: 'Contacts',
                to: '/contacts',
              },
              {
                label: 'Blog',
                to: '/blog',
              },
              {
                label: 'Mentions légales',
                href: '/mentions-legales',
              },
              {
                label: 'Sources du site sur Froggit 🐸',
                href: 'https://lab.frogg.it/lydra/www/lydra.fr',
              },
            ],
        copyright: `Copyright © 2018-${new Date().getFullYear()} Lydra. Tous droits réservés. ` + '<br/>' + `Ce site est fièrement fabriqué avec 🤍 avec des Logiciels Libres et hébergé en 🇫🇷 sur les <a href="https://www.froggit.fr/">Froggit Pages</a>` +"<br/>"+ `Construit avec <a href="https://docusaurus.io/fr">Docusaurus</a>`,
      },
      prism: {
        theme: lightCodeTheme,
        darkTheme: darkCodeTheme,
      },
    }),
};

module.exports = config;
